#!/bin/sh

# Upgrade system: do upgrades
# Copyright (C) 2001 by Erik Cumps <software@mind.be>

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

# $Id: do-upgrade.sh,v 1.2 2001/02/20 00:48:35 slay Exp $
#
# $Log: do-upgrade.sh,v $
# Revision 1.2  2001/02/20 00:48:35  slay
# Updated docs
#
# Revision 1.1  2001/02/20 00:43:54  slay
# New upgrade system
#

#
# Commandline arguments:
#
# do-upgrade.sh pkg pkgbase
#
# where:   pkg		filename of the package (ex: foo-1.2.3.tar.gz)
#          pkgbase	basename of the package directory contained in the
#			package file (ex: foo-1.2.3)
#

#
# Exit codes:
#          0   everything ok
# $EXITERROR   script error
#      other   command error

# === Configuration section ===

VERSION="0.3"
# Error exit code
EXITERROR=255
LOG_INFO="<update cat=\"log\" level=\"info\">"
LOG_ERROR="<update cat=\"log\" level=\"error\">"
END_LOG="</update>"

# === Code section ===

# Get arguments
pkg=$1
pkgbase=$2


if [ $1 = "-z" ]; then
  echo -n $VERSION
  exit 0
fi
# Intro
echo $LOG_INFO "Installing package \"$pkgbase\" in $pkg:" $END_LOG

# Check for package
if [ ! -f $pkg ]; then
  # no such package
  echo $LOG_ERROR "Error: package file not found!" $END_LOG
  exit $EXITERROR
fi

# Check if second argument indeed non-empty
if [ "x$pkgbase" = "x" ]; then
  # empty string
  echo $LOG_ERROR "Error: unknown package name!" $END_LOG
  exit $EXITERROR
fi

# Extract package
echo $LOG_INFO "Extracting package data..." $END_LOG
gunzip -c $pkg | tar -xvf - 1>/dev/null 2>/dev/null
ERROR=$?
if [ $ERROR -ne 0 ]; then
  # error!
  echo $LOG_ERROR "Error: failed to extract package data!" 
  echo "Cleaning up." $END_LOG
  rm -f $pkg 1>/dev/null 2>/dev/null
  rm -rf $pkgbase 1>/dev/null 2>/dev/null
  exit $ERROR
fi

# Install package
echo $LOG_INFO "Installing package..." $END_LOG
cd $pkgbase
if [ ! -x install.sh ]; then
  # install script not executable
  echo $LOG_ERROR "Error: install script \"./$pkgbase/install.sh\" not executable!"
  echo "Cleaning up." $END_LOG
  cd ..
  rm -f $pkg 1>/dev/null 2>/dev/null
  rm -rf $pkgbase 1>/dev/null 2>/dev/null
  exit $EXITERROR
else
  ./install.sh
  ERROR=$?
  if [ $ERROR -eq 2 ]; then
    echo $LOG_ERROR "Error: failed to install package, Cleaning up." $END_LOG
    cd ..
    rm -f $pkg 1>/dev/null 2>/dev/null
    rm -rf $pkgbase 1>/dev/null 2>/dev/null
    exit $ERROR
  fi
  cd ..
fi

# Done
echo $LOG_INFO "Package \"$pkgbase\" installed, cleaning up." $END_LOG

rm -f $pkg 1>/dev/null 2>/dev/null
rm -rf $pkgbase 1>/dev/null 2>/dev/null
exit $ERROR
